#include "finddialog.h"

FindDialog::FindDialog(QWidget *parent)
    : QDialog(parent)
{
    _label = new QLabel(tr("Find &what:"));
    _lineEdit = new QLineEdit;
    _label->setBuddy(_lineEdit);
    //The buddy mechanism is only available for QLabels that contain text
    //in which one character is prefixed with an ampersand, '&'.
    //This character is set as the shortcut key.
    //See the QKeySequence::mnemonic() documentation for details
    //(to display an actual ampersand, use '&&').
    //Alt+w ugrik a Find what után lévő mezőbe

    _caseCheckBox = new QCheckBox(tr("Match &case"));
    _backwardCheckBox = new QCheckBox(tr("Search &backward"));

    _findButton = new QPushButton(tr("&Find"));
    _findButton->setDefault(true);
    _findButton->setEnabled(false);

    _closeButton = new QPushButton(tr("Close"));

    connect(_lineEdit, SIGNAL(textChanged(const QString &)),
            this, SLOT(enableFindButton(const QString &)));
    connect(_findButton, SIGNAL(clicked()),
            this, SLOT(findClicked()));
    connect(_closeButton, SIGNAL(clicked()),
            this, SLOT(close()));

    QHBoxLayout *topLeftLayout = new QHBoxLayout;
    topLeftLayout->addWidget(_label);
    topLeftLayout->addWidget(_lineEdit);

    QVBoxLayout *leftLayout = new QVBoxLayout;
    leftLayout->addLayout(topLeftLayout);
    leftLayout->addWidget(_caseCheckBox);
    leftLayout->addWidget(_backwardCheckBox);

    QVBoxLayout *rightLayout = new QVBoxLayout;
    rightLayout->addWidget(_findButton);
    rightLayout->addWidget(_closeButton);
    rightLayout->addStretch();

    QHBoxLayout *mainLayout = new QHBoxLayout;
    mainLayout->addLayout(leftLayout);
    mainLayout->addLayout(rightLayout);
    setLayout(mainLayout);

    setWindowTitle(tr("Find"));
    setFixedHeight(sizeHint().height());
}

void FindDialog::findClicked()
{
    QString text = _lineEdit->text();
    Qt::CaseSensitivity cs =
            _caseCheckBox->isChecked() ? Qt::CaseSensitive
                                      : Qt::CaseInsensitive;
    if (_backwardCheckBox->isChecked()) {
        emit findPrevious(text, cs);
    } else {
        emit findNext(text, cs);
    }
}

void FindDialog::enableFindButton(const QString &text)
{
    _findButton->setEnabled(!text.isEmpty());
}
