#ifndef TABLAZATKEZELO_H
#define TABLAZATKEZELO_H

#include <QMainWindow>
#include <QClipboard>
#include <QAction>
#include <QToolBar>
#include <QFileDialog>
#include "spreadsheet.h"

#include <QCloseEvent>
#include "finddialog.h"
#include "gotocelldialog.h"


class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QMainWindow *parent = nullptr);
    ~MainWindow();
    QString getFile() const{return _file;}
    void setFile(QString path){_file=path;}

private:
    Spreadsheet* _spreadsheet;
    QToolBar* _fileToolBar;
    QToolBar* _editToolBar;
    QString _file;

    QAction* _actionNew;
    QAction* _actionOpen;
    QAction* _actionSave;
    QAction* _actionCut;
    QAction* _actionCopy;
    QAction* _actionPaste;
    QAction* _actionSearch;
    QAction* _actionGoto;
    QAction* _actionDel;

    FindDialog *_findDialog;

    void createActions();
    void createToolBars();

    bool okToContinue();
    bool loadFile(const QString &fileName);
    bool saveFile(const QString &fileName);

protected:
    void closeEvent(QCloseEvent *event);


private slots:
    void newDocument();
    void openDocument();
    bool saveDocument();
    bool saveAsDocument();

    void copy();
    void paste();
    void cut();
    void search();
    void gotoCell();
    void del();



    void spreadsheetModified();

};

#endif // TABLAZATKEZELO_H
